
Features
-------

Easily build yaml classes and convert to a yaml file when done


Requirements
-------

pip install pyyaml


License
-------

Distributed under the terms of the `BSD-3`_ license, "yaml-designer" is free and open source software


Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.

.. _`BSD-3`: https://opensource.org/licenses/BSD-3-Clause
.. _`file an issue`: https://github.com/MichaelE55/yaml-designer/issues
